django_delayed_union
====================

.. module:: django_delayed_union.base

.. autoclass:: DelayedQuerySet
   :members:
   :undoc-members:

.. module:: django_delayed_union

.. autoclass:: DelayedUnionQuerySet
   :members:
   :show-inheritance:

.. autoclass:: DelayedIntersectionQuerySet
   :members:
   :show-inheritance:

.. autoclass:: DelayedDifferenceQuerySet
   :members:
   :show-inheritance:
